# Crane
#
# Sample Webots controller file for driving the
# underactuated 1-2 pendulum.  The robot has a driven
# base joint between the base and link1, and passive
# joints between link1 and the two distal links link2A
# and link2B.
#
# No copyright, 2020-2021, Garth Zeglin.  This file is
# explicitly placed in the public domain.

print("loading crane.py...")

# Import the Webots simulator API.
from controller import Robot
from controller import Keyboard

# Import the standard Python math library.
import math

print("crane.py waking up...")

# Define the time step in milliseconds between
# controller updates.
EVENT_LOOP_DT = 20

# Request a proxy object representing the robot to
# control.
robot = Robot()
keyboard = Keyboard()
keyboard.enable(EVENT_LOOP_DT)

# Fetch handles for the joint sensors.
j1  = robot.getDevice('baseJoint')
j2 = robot.getDevice('midJoint')

# Specify the sampling rate for the joint sensors.
j1.enable(EVENT_LOOP_DT)
j2.enable(EVENT_LOOP_DT)

# Fetch handle for the 'base' joint motor.  In this
# example the motor will be controlled as a torque
# motor, bypassing the lower-level PID control.
motor1 = robot.getDevice('baseMotor')
motor1.setPosition(0.0)


motor2 = robot.getDevice('midMotor')
motor2.setPosition(0)
#motor2.setTorque(2)

# initial position of motors
q1 = 0
q2 = 0
keyReleased = False


# Run an event loop until the simulation quits,
# indicated by the step function returning -1.
while robot.step(EVENT_LOOP_DT) != -1:

    # Read simulator clock time.
    t = robot.getTime()
    
    key = keyboard.getKey()
    
    if key != -1:
    
        # set torques
        key = chr(key).lower()
        
        if key == 'a':
            motor1.setTorque(-5)
        elif key == 'd':
            motor1.setTorque(5)
        elif key == 'w':
            motor2.setTorque(10)
        elif key == 's':
            motor2.setTorque(-5)
        elif key == 'e':
            motor2.setPosition(0)
        elif key == 'r':
            motor1.setPosition(0)
            
        
            
        keyReleased = True  
        
   
